==> org.apache.sling.caconfig.impl-1.4.12-source-release.zip: org.apache.sling.caconfig.impl-1.4.12/src/main/java/org/apache/sling/caconfig/resource/impl/util/PathEliminateDuplicatesIterator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.caconfig.resource.impl.util;

import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

import org.apache.commons.collections.Predicate;
import org.apache.commons.collections.iterators.FilterIterator;

/**
 * Iterator that eliminates duplicate paths.
 */
public class PathEliminateDuplicatesIterator extends FilterIterator {

    public PathEliminateDuplicatesIterator(Iterator<String> iterator) {
        super(iterator, new Predicate() {
            private final Set<String> resourcePaths = new HashSet<>();
            
            @Override
            public boolean evaluate(Object object) {
                return resourcePaths.add((String)object);
            }
            
        });
    }
    
}

==> org.apache.sling.caconfig.impl-1.7.2-source-release.zip: org.apache.sling.caconfig.impl-1.7.2/src/main/java/org/apache/sling/caconfig/resource/impl/util/PathEliminateDuplicatesIterator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.caconfig.resource.impl.util;

import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

import org.apache.commons.collections4.Predicate;
import org.apache.commons.collections4.iterators.FilterIterator;

/**
 * Iterator that eliminates duplicate paths.
 */
public class PathEliminateDuplicatesIterator extends FilterIterator<String> {

    public PathEliminateDuplicatesIterator(Iterator<String> iterator) {
        super(iterator, new Predicate<String>() {
            private final Set<String> resourcePaths = new HashSet<>();

            @Override
            public boolean evaluate(String object) {
                return resourcePaths.add(object);
            }
        });
    }
}
